	
*This script runs regressions    
*Authors - Christopher Hoy, Jonathan Karver and Revocatus Paul
*Country - Tanzania 


**# We first set the path 

clear
set more off

version 18

set varabbrev on

sysdir set PLUS "CHANGE/PATH/HERE"

ssc install ietoolkit 
ssc install estout
ssc install coefplot

global path "CHANGE/PATH/HERE"
	
	
global data "${path}\data-clean" 
global tables "${path}\tables"


use "$data\final.dta"

* code variables 

* Economic Activity 

encode sector, gen(sector_en)

* Wholesale and retail 

gen whole_sale = 0
replace whole_sale = 1 if sector_en == 21

* Tax region

encode region, gen(tax_region)

** Code region into zones ** 


gen central = 0 
replace central = 1 if (tax_region == 14 | tax_region == 3 | tax_region == 23)
label def central 1 "Central Zone" 0 "Not Central Zone"
label val central central 

gen northern = 0 
replace northern = 1 if (tax_region == 26 | tax_region == 9 | tax_region == 1 | tax_region == 11)
label def northern 1 "Northern Zone" 0 "Not Northern Zone"
label val northern northern 

gen eastern = 0 
replace eastern = 1 if (tax_region == 2 | tax_region == 18)
label def eastern 1 "Eastern Zone" 0 "Not Eastern Zone"
label val eastern eastern 

gen southern = 0 
replace southern = 1 if (tax_region == 10 | tax_region == 15 | tax_region == 20 | tax_region == 17)
label def southern 1 "Southern Zone" 0 "Not Southern Zone"
label val southern southern 

gen southern_high = 0 
replace southern_high = 1 if (tax_region == 5 | tax_region == 13 | tax_region == 19 | tax_region == 7)
label def southern_high 1 "Southern High" 0 "Not Southern High"
label val southern_high southern_high 

gen lake = 0 
replace lake = 1 if (tax_region == 16 | tax_region == 21 | tax_region == 12 | tax_region == 22 | tax_region == 4)
label def lake 1 "Lake Zone" 0 "Not Lake Zone"
label val lake lake

gen western = 0 
replace western = 1 if (tax_region == 25 | tax_region == 8 | tax_region == 6)
label def western 1 "Western Zone" 0 "Not Western Zone"
label val western western 

gen east_south_high = 0 
replace east_south_high = 1 if (tax_region == 5 | tax_region == 13 | tax_region == 19 | tax_region == 7 | tax_region == 2)
label def east_south_high 1 "Estern/Southern Zones" 0 "Other Zones"
label val east_south_high east_south_high 

* Didn't Pay

gen ddnt_pay = 0
replace ddnt_pay = 1 if (date_2022_10 == 0 & date_2022_11 == 0 & date_2022_12 == 0)

* Late

gen late = 0
replace late = 1 if (date_2022_09 == 0 & date_2022_10 > 0 | date_2022_11 > 0)

* Amount Paid and payment vars 

* Amount

gen amount_paid =  date_2023_01 + date_2023_02 + date_2023_03 
gen sin_amount = asinh(amount_paid)

gen amount_paid_q2 =  date_2023_04 + date_2023_05 + date_2023_06 
gen sin_amount_q2 = asinh(amount_paid_q2)

gen amount_paid_q3 =  date_2023_07 + date_2023_08 + date_2023_09 
gen sin_amount_q3 = asinh(amount_paid_q3)

egen all_amount = rowtotal(date_2023_0*)
gen sin_amount_all = asinh(all_amount)

egen amount_2022 = rowtotal(date_2022_*)

* Business size 

gen small = 0
replace small = 1 if amount_2022 < 150000

gen above_50k = 0
replace above_50k = 1 if amount_paid >  50000

* Paid

gen paid_jan = 0
replace paid_jan = 1 if date_2023_01 != 0

gen paid_feb = 0
replace paid_feb = 1 if date_2023_02 != 0

gen paid_march = 0
replace paid_march = 1 if date_2023_03 != 0

gen paid_april = 0
replace paid_april = 1 if date_2023_04 != 0

gen paid_may = 0
replace paid_may = 1 if date_2023_05 != 0

gen paid_june = 0
replace paid_june = 1 if date_2023_06 != 0

gen paid_july = 0
replace paid_july = 1 if date_2023_07 != 0

gen paid_august = 0
replace paid_august = 1 if date_2023_08 != 0

gen paid_september = 0
replace paid_september = 1 if date_2023_09 != 0

gen paid_october = 0
replace paid_october = 1 if date_2023_10 != 0

gen paid_november = 0
replace paid_november = 1 if date_2023_11 != 0

gen paid_q1 = 0
replace paid_q1 = 1 if (paid_jan == 1 | paid_feb == 1 | paid_march == 1)

gen paid_q2 = 0
replace paid_q2 = 1 if (paid_april == 1 | paid_may == 1 | paid_june == 1)

gen paid_q3 = 0
replace paid_q3 = 1 if (paid_july == 1 | paid_august == 1 | paid_september == 1)

gen paid_any = 0 
replace paid_any = 1 if (paid_jan == 1 | paid_feb == 1 | paid_march == 1 | ///
paid_april == 1 | paid_may == 1 | paid_june == 1 | paid_july == 1 | paid_august == 1 | paid_september == 1)

gen above_outdar = 0
replace above_outdar = 1 if (eastern == 0 & above_50k == 1)


* Balance Test 

gen pay_trend_1 = date_2022_11
gen pay_trend_2 = date_2022_10 + date_2022_11
gen pay_trend_3 = date_2022_09 + date_2022_10 + date_2022_11
gen pay_trend_5 = date_2022_11+ date_2022_10 + date_2022_09 + date_2022_08 + date_2022_07
gen pay_trend_12 = date_2023_06 + date_2023_05 + date_2023_04 + date_2023_03 + date_2023_02 + date_2023_01 + date_2022_12 + date_2022_11+ date_2022_10 + date_2022_09 + date_2022_08 + date_2022_07
iebaltab pay_trend_3 pay_trend_5, grpvar(treatment) savetex("$tables\balance.tex") replace


* Interactions 

foreach var of varlist eastern east_south_high whole_sale ddnt_pay late above_50k above_outdar small central northern southern southern_high lake western {
gen not_`var' = 1 if `var' == 0 
replace not_`var' = 0 if `var' == 1
}

foreach var of varlist eastern east_south_high whole_sale ddnt_pay late above_50k above_outdar small central northern southern southern_high lake western {
gen `var'_treat = `var'*treatment
}

foreach var of varlist not_eastern not_east_south_high not_whole_sale not_ddnt_pay not_late not_above_50k not_above_outdar not_small not_central not_northern not_southern not_southern_high not_lake not_western {
gen `var'_treat = `var'*treatment
}

	
* Overall treatment effects

local treat_mean
foreach reg of varlist paid_q1 sin_amount paid_q2 sin_amount_q2 paid_q3 sin_amount_q3 {
    reg `reg' treatment whole_sale ddnt_pay eastern late small, vce(cluster ward)
    eststo `reg'
    local treat_mean `treat_mean' `reg'
}

esttab `treat_mean' using "$tables\heterogenous.tex", ///
prehead("{ \def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi} \begin{tabular*}{\hsize}{@{\hskip\tabcolsep\extracolsep\fill}l*{8}{c}} \hline\hline") ///
cells(b(star fmt(3)) se(par fmt(2)) p) label star(* 0.05 ** 0.01 *** 0.001) ///
nonumbers keep(treatment) varlabels(treatment "Treatment group mean") fragment noobs ///
mtitles("Paid Q1" "Amount Q1" "Paid Q2" "Amount Q2" "Paid Q3" "Amount Q3") nonumbers replace

coefplot `treat_mean', vertical keep(treatment) yline(0) levels(90) legend(cols(1) rows(1) size(small)) coeflabels(treatment = " ") ///
	ytitle("Treatment Effect") plotlabels("Paid Q1" "Amount Paid" "Paid Q2" "Amount Paid Q2" "Paid Q3" "Amount Paid Q3")

* Heterogeneous treatment effects


* In Eastern Zone

local hete_eastern
foreach reg of varlist paid_q1 sin_amount paid_q2 sin_amount_q2 paid_q3 sin_amount_q3 {
    reg `reg' not_eastern_treat eastern_treat  eastern ddnt_pay whole_sale late small, vce(cluster ward)
    test eastern_treat = not_eastern_treat
    estadd scalar p_diff = r(p)
    eststo `reg'
    local hete_eastern `hete_eastern' `reg'
}

esttab `hete_eastern' using "$tables\heterogenous.tex", append ///
    keep(eastern_treat not_eastern_treat) varlabels(eastern_treat "Treated X Eastern Zone" not_eastern_treat "Treated X Not Eastern Zone") nonumbers ///
    cells(b(star fmt(3)) se(par fmt(2)) p) stats(p_diff) label star(* 0.05 ** 0.01 *** 0.001) noobs ///
    nomtitles fragment collabels(none) nolines posthead("\hline")
	
	coefplot `hete_eastern', vertical keep(not_eastern_treat eastern_treat ) drop(_cons) yline(0) levels(90) legend(cols(1) rows(1) size(small)) coeflabels(eastern_treat = "Treated X Eastern Zone " not_eastern_treat = "Treated X Not Eastern Zone") ///
	ytitle("Treatmeant Effect") ///
	scheme(stcolor) plotlabels("Paid Q1" "Amount Paid")
    

* In Central Zone

local hete_central
foreach reg of varlist paid_q1 sin_amount paid_q2 sin_amount_q2 paid_q3 sin_amount_q3 {
    reg `reg' central_treat not_central_treat central ddnt_pay whole_sale late small, vce(cluster ward)
    test central_treat = not_central_treat
    estadd scalar p_diff = r(p)
    eststo `reg'
    local hete_central `hete_central' `reg'
}

esttab `hete_central' using "$tables\heterogenous.tex", append ///
    keep(central_treat not_central_treat) varlabels(central_treat "Treated X Central Zone" not_central_treat "Treated X Not Central Zone") nonumbers ///
    cells(b(star fmt(3)) se(par fmt(2)) p) stats(p_diff) label star(* 0.10 ** 0.05 *** 0.01) noobs ///
    nomtitles fragment collabels(none) nolines posthead("\hline")	
	
* In Northern Zone

local hete_northern
foreach reg of varlist paid_q1 sin_amount paid_q2 sin_amount_q2 paid_q3 sin_amount_q3 {
    reg `reg' northern_treat not_northern_treat northern ddnt_pay whole_sale late small, vce(cluster ward)
    test northern_treat = not_northern_treat
    estadd scalar p_diff = r(p)
    eststo `reg'
    local hete_northern `hete_northern' `reg'
}

esttab `hete_northern' using "$tables\heterogenous.tex", append ///
    keep(northern_treat not_northern_treat) varlabels(northern_treat "Treated X Northern Zone" not_northern_treat "Treated X Not Northern Zone") nonumbers ///
    cells(b(star fmt(3)) se(par fmt(2)) p) stats(p_diff) label star(* 0.10 ** 0.05 *** 0.01) noobs ///
    nomtitles fragment collabels(none) nolines posthead("\hline")	
	
	
* In Southern Zone

local hete_southern
foreach reg of varlist paid_q1 sin_amount paid_q2 sin_amount_q2 paid_q3 sin_amount_q3 {
    reg `reg' southern_treat not_southern_treat southern ddnt_pay whole_sale late small, vce(cluster ward)
    test southern_treat = not_southern_treat
    estadd scalar p_diff = r(p)
    eststo `reg'
    local hete_southern `hete_southern' `reg'
}

esttab `hete_southern' using "$tables\heterogenous.tex", append ///
    keep(southern_treat not_southern_treat) varlabels(southern_treat "Treated X Southern Zone" not_southern_treat "Treated X Not Southern Zone") nonumbers ///
    cells(b(star fmt(3)) se(par fmt(2)) p) stats(p_diff) label star(* 0.05 ** 0.01 *** 0.001) noobs ///
    nomtitles fragment collabels(none) nolines posthead("\hline")	
	
	
* In Southern Highlands Zone

local hete_southern_high
foreach reg of varlist paid_q1 sin_amount paid_q2 sin_amount_q2 paid_q3 sin_amount_q3 {
    reg `reg' southern_high_treat not_southern_high_treat southern_high ddnt_pay whole_sale late small, vce(cluster ward)
    test southern_high_treat = not_southern_high_treat
    estadd scalar p_diff = r(p)
    eststo `reg'
    local hete_southern_high `hete_southern_high' `reg'
}

esttab `hete_southern_high' using "$tables\heterogenous.tex", append ///
    keep(southern_high_treat not_southern_high_treat) varlabels(southern_high_treat "Treated X Southern High Zone" not_southern_high_treat "Treated X Not Southern High Zone") nonumbers nomtitles fragment collabels(none) ///
    stats(p_diff N, fmt(3 0) labels("p_diff" "Observations")) ///
    nolines cells(b(star fmt(3)) se(par fmt(2)) p) label star(* 0.05 ** 0.01 *** 0.001) ///
    posthead("\hline") postfoot("\hline \multicolumn{8}{p{\linewidth}}{\footnotesize Standard errors in parentheses}\\\multicolumn{8}{l}{\footnotesize \sym{*} \(p<0.05\), \sym{**} \(p<0.01\), \sym{***} \(p<0.01\)}\\ \multicolumn{8}{p{\linewidth}}{\footnotesize Note: Paid Q1 represents taxpayers who paid their taxes between January and March 2023. Paid Q2 represents taxpayers who paid their taxes between April and June 2023. Paid Q3 represents taxpayers who paid their taxes between July and September 2023. Amount Q1, Q2, and Q3 refer to the sum paid by a taxpayer in the first three quarters of 2023. The Eastern Zone represents taxpayers in the Dar es Salaam tax region (Kinondoni, Ilala, Temeke, Tegeta, and Kariakoo tax regions) and the Pwani tax region. The Central Zone represents taxpayers from the Morogoro, Dodoma, and Singida tax regions. The Northern Zone represents taxpayers from the Tanga, Kilimanjaro, Arusha, and Manyara tax regions. The Southern High represents taxpayers from the Southern Highlands regions of Iringa, Mbeya, Rukwa, and Katavi. The Southern Zone represents taxpayers from the Lindi, Mtwara, Ruvuma, and Njombe regions.} \\\end{tabular*} }")	
	
