


**Basic code for regressions **



global data "${path}\data" 
global results "${path}\results\tables"




**Import data**



clear
set more off
use "$data\analysis\prepared.dta"


**Overall treatment effects - Tax***	 



*Own tax paying behavior*


/// This loop regresses our primary outcomes on our background variables and produces a table in tex format

local treat_own
foreach reg_3 of varlist direct not_punishable avoid_paying refuse own_index{
	reg `reg_3' treatment owner soletrader age male TObelow_1mil region district education involvement wr_trade, vce(cluster A4_num)
	eststo `reg_3'
	local treat_own `treat_own' `reg_3'
}
esttab `treat_own' using "$results\overall_own.tex", ///
	prehead("{ \def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi} \begin{center} \begin{tabular*}{\hsize}{@{\hskip\tabcolsep\extracolsep\fill}l*{6}{c}} \multicolumn{6}{c}{Table 1: Overall Treatment Effects - Own Paying Behaviour} \\\\ \hline\hline") ///
	cells(b(star fmt(3)) se(par fmt(2)) p) label star(* 0.10 ** 0.05 *** 0.01) fragment ///
	mtitles("Direct" "Punishable" "Will Pay" "Wont Refuse" "INDEX") keep(treatment) varlabels(treatment "Treatment group mean") nonumbers noobs replace

local cons_own
foreach reg_1 of varlist direct not_punishable avoid_paying refuse own_index{
	reg `reg_1' treatment, vce(cluster A4_num)
	eststo `reg_1'
	local cons_own `cons_own' `reg_1'
}
esttab `cons_own' using "$results\overall_own.tex", append cells(b(fmt(3))) ///
	keep(_cons) varlabels(_cons "Control group mean") nonumbers ///
	nomtitles fragment collabels(none) stats(N, fmt(%8.0g) labels("Observations")) nolines ///
	postfoot("\hline \multicolumn{6}{p{\linewidth}}{\footnotesize Standard errors in parentheses}\\\multicolumn{6}{l}{\footnotesize \sym{*} \(p<0.10\), \sym{**} \(p<0.05\), \sym{***} \(p<0.01\)}\\ \multicolumn{6}{p{\linewidth}}{\footnotesize Note: This Table shows heterogenous treatment effects. Model Names (Direct Punishable Will Pay Wont Refuse INDEX) represent our outcome variables. Direct: Based on question C11 that states : My firm does not pay all the [Direct taxes] it is required to pay. Punishable: based on question D19 that asks respondent to state whether Firms not paying the taxes they owe to the government is Not wrong at all, Wrong but understandable or Wrong and punishable. Will Pay - based on question D20a, that states If I was sure I would not get caught, I would not pay all the taxes that I owe. Wont Refuse: based on question D20d that states Firms should refuse to pay taxes until they get better services from the national government. INDEX: An unweighted average of the Z-scores of all four outcome variables} \\\end{tabular*} }") 



* Secondary Outcomes*

local cons_sec_1
foreach reg of varlist aware_oblgtns easy_process reward_compliance supplier_compliance legal_act_high {
    reg `reg' treatment owner soletrader age male TObelow_1mil region district education involvement wr_trade, vce(cluster A4_num)
    eststo `reg'
    local cons_sec_1 `cons_sec_1' `reg'
}

esttab `cons_sec_1' using "$results\overall_sec.tex", ///
    prehead("{ \def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi} \begin{center} \begin{tabular*}{\hsize}{@{\hskip\tabcolsep\extracolsep\fill}l*{11}{c}} \multicolumn{6}{c}{Table 3: Overall Treatment Effects - Secondary Outcomes} \\\\ \hline\hline") ///
    cells(b(star fmt(3)) se(par fmt(2)) p) label star(* 0.10 ** 0.05 *** 0.01) ///
    nonumbers keep(treatment) varlabels(treatment "Treatment group mean") fragment noobs ///
    mtitles("Aware Obligations" "Easy Process" "Reward Compliance" "Supplier Compliance" "Legal Action High") replace

local cons_sec_11
foreach reg of varlist aware_oblgtns easy_process reward_compliance supplier_compliance legal_act_high {
    reg `reg' treatment, vce(cluster A4_num)
    eststo `reg'
    local cons_sec_11 `cons_sec_11' `reg'
}

esttab `cons_sec_11' using "$results\overall_sec.tex", append cells(b(fmt(3))) ///
    keep(_cons) varlabels(_cons "Control group mean") nonumbers ///
    nomtitles fragment collabels(none) stats(N, fmt(%8.0g) labels("Observations")) nolines ///
    postfoot("\hline \multicolumn{11}{p{\linewidth}}{\footnotesize Standard errors in parentheses}\\\multicolumn{11}{l}{\footnotesize \sym{*} \(p<0.10\), \sym{**} \(p<0.05\), \sym{***} \(p<0.01\)}\\ \multicolumn{11}{p{\linewidth}}{\footnotesize Note: This Table shows the overall impact of the treatment relative to the control group. Model Names (Aware Obligations, Easy Process, Reward Compliance, Supplier Compliance, Legal Action High) represent our secondary outcome variables Aware Obligations: Based on question C12a that states I am fully aware of my firm's tax obligations. Easy Process: Based on question C12d that states The process of declaring and paying taxes is easy. Reward Compliance: Based on question C12e that states Recognizing and rewarding tax compliant behavior is better than punishing non compliance. Supplier Compliance: Based on question C12f that states When my firm chooses suppliers/service providers, it considers whether they pay taxes. Legal Action High: Based on question C12g that states The risk of legal action for firms evading or underpaying taxes in Tanzania is high} \\\end{tabular*} }")

* Balance Test 


stddiff i.owner i.soletrader i.male i.TObelow_1mil i.wr_trade, by(treatment)  
